build.M.c: build.M.c

Description Usage Arguments Value Examples

View source: R/contrastMatrix.R

Description

Build the contrast matrix based on a complete graph with n nodes

Usage

1

Arguments

n

number of nodes for the complete graph

Value

Returns the contrast matrix of a complete graph with n nodes

Examples

1

wenda-1121/HP documentation built on Feb. 22, 2020, 1:28 a.m.